@@ -59,17 +59,11 @@ def dynamic_import(module_path: str, namespace: dict, all_imports = None):
     all_imports = if_none_change(all_imports,True)
     if module_path:
         module = importlib.import_module(module_path)
-
         # Import literally everything except dunders, unless you want them too.
         names = [n for n in dir(module) if n and ((not all_imports and not n.startswith("_")) or all_imports)]
-
-
         for name in names:
             namespace[name] = getattr(module, name)
-
         return module
-
-
 def get_monorepo_root(directory=None,files=None):
     directory = directory or get_initial_caller_dir()
     
@@ -83,10 +77,10 @@ def switch_to_monorepo_root(directory=None,files=None):
         sys.path.insert(0, str(monorepo_root))
     return str(monorepo_root)
 def get_all_imports(directory=None,sysroot=None,globs=None):
-    globs= globs or get_globals_from_path() or globals()
+    globs = globs or get_true_globals() or globals()
     directory = directory or get_initial_caller_dir()
-    files = get_py_files(directory=directory)
-    sysroot = sysroot or switch_to_monorepo_root(directory=directory)
+    files = collect_globs(directory=directory,allowed_exts='.py').get('files')
+    sysroot = sysroot or switch_to_monorepo_root(directory=directory,files=files)
     for glo in files:
         imp = get_import_with_sysroot(glo, sysroot)
         dynamic_import(imp, globs)
